local MAJOR, MINOR = "LibArkPetJournal-1.0", 1
local lib, oldminor = LibStub:NewLibrary( MAJOR, MINOR )

if not lib then return end


local _G = _G
local select = _G.select
local pairs = _G.pairs
local ipairs = _G.ipairs
local string = _G.string
local type = _G.type
local error = _G.error
local table = _G.table


lib.callbacks = lib.callbacks or LibStub( "CallbackHandler-1.0" ):New( lib )

lib.event_frame = lib.event_frame or CreateFrame( "FRAME" )
lib.event_frame:SetScript( "OnEvent", function( frame, event, ... )
    frame[event]( frame, ... )
end )

--[[
	
	if the pet frame is open ignore updates
	
	pet rename
	pet cage
	pet release
	pet favourite
	
	pet level up
	pet quality change
	
	rescan when the pet window closes
	
--]]

lib._petdata = lib._petdata or { }
lib._pid = lib._pid or { }
lib._sid = lib._sid or { }
lib._cid = lib._cid or { }

function lib:ScanPet( )
	
	-- clear pet filters
	
	wipe( lib._petdata )
	
	wipe( lib._pid )
	wipe( lib._sid )
	wipe( lib._cid )
	
	local total, owned = C_PetJournal.GetNumPets( false )
	
    if ( total == 0 ) and ( owned == 0 ) then
        --lib:RestoreFilters()
        lib.event_frame:Show( )
        return
    end
	
    lib._pettotal = total
    lib._petowned = owned
	
    for i = 1, total do
		
        local petID, speciesID, isOwned, _, _, _, _, _, _, _, creatureID = C_PetJournal.GetPetInfoByIndex( i, false )
		
		if ( i == 1 ) and ( isOwned ) then
			
			local name = select( 8, C_PetJournal.GetPetInfoByPetID( petID ) )
            if not name then
                --lib:RestoreFilters()
                --start_background()
                return false
            end
			
		end
		
		if isOwned then
			lib._pid[petID] = true
			lib._sid[speciesID] = true
			lib._cid[creatureID] = true
		end

		
		lib._petdata[petID] = { pid = petID, own = isOwned, sid = speciesID, cid = creatureID }
		
	end
	
	lib.callbacks:Fire( "PetListUpdated", lib, false )
	
	--lib:RestoreFilters()
	
	return true
	
end





-- externally available functions

function lib:GetSpeciesIDForCreatureID( creatureID )
	
end

function lib:GetSpeciesIDfromGUID( guid )
	
	local unitType = tonumber( string.format( "0x%s", string.sub( guid, 3, 5 ) ) )
	unitType = bit.band( unitType, 0x00f )
	
	if ( unitType == 0x003 ) then
		local creatureID = tonumber( string.format( "0x%s", string.sub( guid, 7, 10 ) ) )
		return lib:GetSpeciesIDForCreatureID( creatureID )
	end
	
end
